@@ -120,6 +120,8 @@
 // set this to true in gconf/dconf when using with gnome global menus
 #define ENABLE_GLOBAL_MENU  "enable-global-menu"
 
+#define ENABLE_NAUTILUS_PLUGIN "enable-nautilus-plugin"
+
 // JavaScript Playstates
 #define STATE_UNDEFINED     0
 #define STATE_STOPPED       1
@@ -343,6 +345,7 @@ gboolean disable_context_menu;
 gboolean disable_fullscreen;
 gboolean disable_pause_on_click;
 gboolean enable_global_menu;
+gboolean enable_nautilus_plugin;
 gint loop;
 gint start_second;
 gint play_length;
@@ -429,9 +432,6 @@ gint tv_width;
 gint tv_height;
 gint tv_fps;
 
-GMutex *slide_away;
-GCond *mplayer_complete_cond;
-
 GThreadPool *retrieve_metadata_pool;
 
 gboolean use_mediakeys;
