@@ -263,6 +263,7 @@ GtkWidget *config_use_mediakeys;
 GtkWidget *config_use_defaultpl;
 GtkWidget *config_disable_animation;
 GtkWidget *config_mouse_wheel;
+GtkWidget *config_enable_nautilus_plugin;
 
 GtkWidget *config_alang;
 GtkWidget *config_slang;
@@ -361,3 +362,4 @@ gint get_index_from_key_and_modifier(guint key, GdkModifierType modifier);
 
 void show_fs_controls();
 void hide_fs_controls();
+gboolean set_destroy(gpointer data);
