@@ -585,8 +585,6 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         gmtk_media_player_set_state(GMTK_MEDIA_PLAYER(media), MEDIA_STATE_PLAY);
 
     }
-    autostart = 1;
-
 
     return 0;
 }
@@ -596,6 +594,7 @@ static void hup_handler(int signum)
 {
     // printf("handling signal %i\n",signum);
     delete_callback(NULL, NULL, NULL);
+    g_idle_add(set_destroy, NULL);
 }
 #endif
 
@@ -647,7 +646,7 @@ void assign_default_keys()
 
 int main(int argc, char *argv[])
 {
-    struct stat buf;
+    struct stat buf = { 0 };
     struct mntent *mnt = NULL;
     FILE *fp = NULL;
     gchar *uri;
@@ -658,7 +657,10 @@ int main(int argc, char *argv[])
     gdouble volume = 100.0;
     gchar *accelerator_keys;
     gchar **parse;
+#ifdef GTK3_ENABLED
     GtkSettings *gtk_settings;
+#endif
+    int stat_result;
 
 #ifndef OS_WIN32
     struct sigaction sa;
@@ -733,7 +735,6 @@ int main(int argc, char *argv[])
     subtitle_fuzziness = 0;
     disable_embeddedfonts = FALSE;
     quit_on_complete = FALSE;
-    slide_away = NULL;
     verbose = 0;
     reallyverbose = 0;
     embedding_disabled = FALSE;
@@ -901,6 +902,8 @@ int main(int argc, char *argv[])
         enable_global_menu = (g_getenv("UBUNTU_MENUPROXY") == NULL ? FALSE : TRUE);
     }
 
+    enable_nautilus_plugin = gm_pref_store_get_boolean_with_default(gm_store, ENABLE_NAUTILUS_PLUGIN, TRUE);
+
     mplayer_bin = gm_pref_store_get_string(gm_store, MPLAYER_BIN);
     if (mplayer_bin != NULL && !g_file_test(mplayer_bin, G_FILE_TEST_EXISTS)) {
         g_free(mplayer_bin);
@@ -1052,17 +1055,17 @@ int main(int argc, char *argv[])
                            G_TYPE_STRING, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT,
                            G_TYPE_FLOAT, G_TYPE_FLOAT, G_TYPE_BOOLEAN);
 
-    // only use dark theme if not embedded, otherwise use the default theme                                       
+    // only use dark theme if not embedded, otherwise use the default theme  
+#ifdef GTK3_ENABLED
     if (embed_window <= 0) {
         gtk_settings = gtk_settings_get_default();
         g_object_set(G_OBJECT(gtk_settings), "gtk-application-prefer-dark-theme", TRUE, NULL);
     }
+#endif
 
     create_window(embed_window);
 
     autopause = FALSE;
-    slide_away = g_mutex_new();
-    mplayer_complete_cond = g_cond_new();
 #ifdef GIO_ENABLED
     idledata->caching = g_mutex_new();
     idledata->caching_complete = g_cond_new();
@@ -1073,19 +1076,29 @@ int main(int argc, char *argv[])
     if (argv[fileindex] != NULL) {
 #ifdef GIO_ENABLED
         file = g_file_new_for_commandline_arg(argv[fileindex]);
+        stat_result = -1;
         if (file != NULL) {
-            uri = g_file_get_uri(file);
+            GError *error = NULL;
+            GFileInfo *file_info = g_file_query_info(file, G_FILE_ATTRIBUTE_UNIX_MODE, 0, NULL, &error);
+            if (file_info != NULL) {
+                buf.st_mode = g_file_info_get_attribute_uint32(file_info, G_FILE_ATTRIBUTE_UNIX_MODE);
+                stat_result = 0;
+                g_object_unref(file_info);
+            }
+            if (error != NULL) {
+                if (verbose)
+                    printf("failed to get mode: %s\n", error->message);
+                g_error_free(error);
+            }
             g_object_unref(file);
         }
-        filename = g_filename_from_uri(uri, NULL, NULL);
-        g_stat(filename, &buf);
-        g_free(filename);
 #else
-        g_stat(argv[fileindex], &buf);
+        stat_result = g_stat(argv[fileindex], &buf);
 #endif
 
         if (verbose) {
             printf("opening %s\n", argv[fileindex]);
+            printf("stat_result = %i\n", stat_result);
             printf("is block %i\n", S_ISBLK(buf.st_mode));
             printf("is character %i\n", S_ISCHR(buf.st_mode));
             printf("is reg %i\n", S_ISREG(buf.st_mode));
@@ -1093,7 +1106,7 @@ int main(int argc, char *argv[])
             printf("playlist %i\n", playlist);
             printf("embedded in window id 0x%x\n", embed_window);
         }
-        if (S_ISBLK(buf.st_mode)) {
+        if (stat_result == 0 && S_ISBLK(buf.st_mode)) {
             // might have a block device, so could be a DVD
 
 #ifdef HAVE_SYS_MOUNT_H
@@ -1148,11 +1161,11 @@ int main(int argc, char *argv[])
                     playiter = TRUE;
                 }
             }
-        } else if (S_ISDIR(buf.st_mode)) {
+        } else if (stat_result == 0 && S_ISDIR(buf.st_mode)) {
             uri = g_strdup_printf("%s/VIDEO_TS", argv[fileindex]);
-            stat(uri, &buf);
+            stat_result = g_stat(uri, &buf);
             g_free(uri);
-            if (S_ISDIR(buf.st_mode)) {
+            if (stat_result == 0 && S_ISDIR(buf.st_mode)) {
                 add_item_to_playlist("dvdnav://", 0);
                 gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
                 gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_DVD);
