@@ -22,6 +22,9 @@
  * 	Boston, MA  02110-1301, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gstdio.h>
