@@ -1096,6 +1096,7 @@ MetaData *get_basic_metadata(gchar * uri)
     }
 
     if (ret != NULL) {
+        ret->uri = g_strdup(uri);
         ret->title = g_strdup(title);
         ret->artist = g_strdup(artist);
         ret->album = g_strdup(album);
@@ -1390,6 +1391,7 @@ MetaData *get_metadata(gchar * uri)
     }
 
     if (ret != NULL) {
+        ret->uri = g_strdup(uri);
         ret->title = g_strdup(title);
         ret->artist = g_strdup(artist);
         ret->album = g_strdup(album);
@@ -2415,7 +2417,8 @@ gpointer get_cover_art(gpointer data)
     FILE *art;
     gpointer pixbuf;
     MetaData *metadata = (MetaData *) data;
-    gboolean art_found = TRUE;
+    gchar *md5;
+    gchar *thumbnail;
 #ifdef GIO_ENABLED
     GFile *file;
 #endif
@@ -2434,7 +2437,7 @@ gpointer get_cover_art(gpointer data)
     }
 
     path = g_strdup(metadata->uri);
-    if (path != NULL) {
+    if (path != NULL && cache_file == NULL) {
         p = g_strrstr(path, "/");
         if (p != NULL) {
             p[0] = '\0';
@@ -2451,10 +2454,10 @@ gpointer get_cover_art(gpointer data)
                 printf("Looking for cover art at %s\n", cache_file);
 
         }
-        g_free(path);
-        path = NULL;
         p = NULL;
     }
+    g_free(path);
+    path = NULL;
 
     if (metadata->uri != NULL && (cache_file == NULL || !g_file_test(cache_file, G_FILE_TEST_EXISTS))) {
         path = g_strdup(metadata->uri);
@@ -2486,6 +2489,10 @@ gpointer get_cover_art(gpointer data)
         cache_file =
             g_strdup_printf("%s/gnome-mplayer/cover_art/%s/%s.jpeg", g_get_user_cache_dir(),
                             metadata->artist, metadata->album);
+        if (!g_file_test(cache_file, G_FILE_TEST_EXISTS)) {
+            g_free(cache_file);
+            cache_file = NULL;
+        }
     }
 
     if (local_artist) {
@@ -2497,8 +2504,7 @@ gpointer get_cover_art(gpointer data)
         metadata->album = NULL;
     }
 
-    if (!g_file_test(cache_file, G_FILE_TEST_EXISTS)) {
-        art_found = FALSE;
+    if (cache_file == NULL) {
         if (!disable_cover_art_fetch) {
             url = get_cover_art_url(metadata->artist, metadata->title, metadata->album);
             if (url == NULL && metadata->album != NULL && strlen(metadata->album) > 0) {
@@ -2562,15 +2568,45 @@ gpointer get_cover_art(gpointer data)
                     }
                     // printf("cover art url is %s\n",url);
                     g_free(url);
-                    art_found = TRUE;
                 }
-            } else {
-                art_found = TRUE;
             }
         }
     }
 
-    if (g_file_test(cache_file, G_FILE_TEST_EXISTS) && art_found) {
+    if (verbose)
+        printf("metadata->uri = %s\ncache_file=%s\n", metadata->uri, cache_file);
+
+    if (metadata->uri != NULL && cache_file == NULL) {
+        md5 = g_compute_checksum_for_string(G_CHECKSUM_MD5, metadata->uri, -1);
+        thumbnail = g_strdup_printf("%s/.thumbnails/normal/%s.png", g_get_home_dir(), md5);
+
+        if (g_file_test(thumbnail, G_FILE_TEST_EXISTS)) {
+            if (cache_file)
+                g_free(cache_file);
+            cache_file = g_strdup(thumbnail);
+            if (verbose) {
+                printf("Using thumbnail %s as image\n", thumbnail);
+            }
+        }
+        g_free(thumbnail);
+
+        if (cache_file == NULL) {
+            thumbnail = g_strdup_printf("%s/.thumbnails/large/%s.png", g_get_home_dir(), md5);
+
+            if (g_file_test(thumbnail, G_FILE_TEST_EXISTS)) {
+                if (cache_file)
+                    g_free(cache_file);
+                cache_file = g_strdup(thumbnail);
+                if (verbose) {
+                    printf("Using thumbnail %s as image\n", thumbnail);
+                }
+            }
+            g_free(thumbnail);
+        }
+        g_free(md5);
+    }
+
+    if (cache_file != NULL && g_file_test(cache_file, G_FILE_TEST_EXISTS)) {
         pixbuf = gdk_pixbuf_new_from_file(cache_file, NULL);
         g_idle_add(set_cover_art, pixbuf);
     } else {
